@@ -37,7 +37,7 @@ type CheClusterSpec struct {
 	// +optional
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,order=1
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Development environments"
-	// +kubebuilder:default:={disableContainerBuildCapabilities: true, defaultComponents: {{name: universal-developer-image, container: {image: "quay.io/devfile/universal-developer-image:ubi8-38da5c2"}}}, defaultEditor: che-incubator/che-code/insiders, storage: {pvcStrategy: per-user}, defaultNamespace: {template: <username>-devspaces, autoProvision: true}, secondsOfInactivityBeforeIdling:1800, secondsOfRunBeforeIdling:-1}
+	// +kubebuilder:default:={disableContainerBuildCapabilities: true, defaultComponents: {{name: universal-developer-image, container: {image: "quay.io/devfile/universal-developer-image:ubi8-38da5c2"}}}, defaultEditor: che-incubator/che-code/latest, storage: {pvcStrategy: per-user}, defaultNamespace: {template: <username>-devspaces, autoProvision: true}, secondsOfInactivityBeforeIdling:1800, secondsOfRunBeforeIdling:-1, startTimeoutSeconds:300, maxNumberOfWorkspacesPerUser:-1}
 	DevEnvironments CheClusterDevEnvironments `json:"devEnvironments"`
 	// Che components configuration.
 	// +optional
@@ -90,7 +90,7 @@ type CheClusterDevEnvironments struct {
 	// The plugin ID must have `publisher/plugin/version` format.
 	// The URI must start from `http://` or `https://`.
 	// +optional
-	// +kubebuilder:default:=che-incubator/che-code/insiders
+	// +kubebuilder:default:=che-incubator/che-code/latest
 	DefaultEditor string `json:"defaultEditor,omitempty"`
 	// Default components applied to DevWorkspaces.
 	// These default components are meant to be used when a Devfile, that does not contain any components.
@@ -119,6 +119,28 @@ type CheClusterDevEnvironments struct {
 	// +kubebuilder:validation:Pattern=^[a-z0-9]([-a-z0-9]*[a-z0-9])?$
 	// +kubebuilder:validation:MaxLength=63
 	ServiceAccount string `json:"serviceAccount,omitempty"`
+	// Pod scheduler for the workspace pods.
+	// If not specified, the pod scheduler is set to the default scheduler on the cluster.
+	// +optional
+	PodSchedulerName string `json:"podSchedulerName,omitempty"`
+	// StartTimeoutSeconds determines the maximum duration (in seconds) that a workspace can take to start
+	// before it is automatically failed.
+	// If not specified, the default value of 300 seconds (5 minutes) is used.
+	// +optional
+	// +kubebuilder:validation:Minimum:=1
+	// +kubebuilder:default:=300
+	StartTimeoutSeconds *int32 `json:"startTimeoutSeconds,omitempty"`
+	// Total number of workspaces, both stopped and running, that a user can keep.
+	// The value, -1, allows users to keep an unlimited number of workspaces.
+	// +kubebuilder:validation:Minimum:=-1
+	// +kubebuilder:default:=-1
+	// +optional
+	MaxNumberOfWorkspacesPerUser *int64 `json:"maxNumberOfWorkspacesPerUser,omitempty"`
+	// The maximum number of running workspaces per user.
+	// The value, -1, allows users to run an unlimited number of workspaces.
+	// +kubebuilder:validation:Minimum:=-1
+	// +optional
+	MaxNumberOfRunningWorkspacesPerUser *int64 `json:"maxNumberOfRunningWorkspacesPerUser,omitempty"`
 }
 
 // Che components configuration.
@@ -349,6 +371,7 @@ type ImagePuller struct {
 // See https://github.com/devfile/devworkspace-operator
 // +k8s:openapi-gen=true
 type DevWorkspace struct {
+	// Deprecated in favor of `MaxNumberOfRunningWorkspacesPerUser`
 	// The maximum number of running workspaces per user.
 	// +optional
 	RunningLimit string `json:"runningLimit,omitempty"`
@@ -394,12 +417,13 @@ type WorkspaceStorage struct {
 	// +optional
 	PerWorkspaceStrategyPvcConfig *PVC `json:"perWorkspaceStrategyPvcConfig,omitempty"`
 	// Persistent volume claim strategy for the Che server.
-	// The supported strategies are: `per-user` (all workspaces PVCs in one volume)
-	// and 'per-workspace' (each workspace is given its own individual PVC).
-	// For details, see https://github.com/eclipse/che/issues/21185.
+	// The supported strategies are: `per-user` (all workspaces PVCs in one volume),
+	// `per-workspace` (each workspace is given its own individual PVC)
+	// and `ephemeral` (non-persistent storage where local changes will be lost when
+	// the workspace is stopped.)
 	// +optional
 	// +kubebuilder:default:="per-user"
-	// +kubebuilder:validation:Enum=common;per-user;per-workspace
+	// +kubebuilder:validation:Enum=common;per-user;per-workspace;ephemeral
 	PvcStrategy string `json:"pvcStrategy,omitempty"`
 }
 
@@ -585,6 +609,10 @@ type CheClusterGitServices struct {
 	// +optional
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Bitbucket"
 	BitBucket []BitBucketService `json:"bitbucket,omitempty"`
+	// Enables users to work with repositories hosted on Azure DevOps Service (dev.azure.com).
+	// +optional
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Azure"
+	AzureDevOps []AzureDevOpsService `json:"azure,omitempty"`
 }
 
 // GitHubService enables users to work with repositories hosted on GitHub (GitHub.com or GitHub Enterprise).
@@ -636,6 +664,15 @@ type BitBucketService struct {
 	Endpoint string `json:"endpoint,omitempty"`
 }
 
+// AzureDevOpsService enables users to work with repositories hosted on Azure DevOps Service (dev.azure.com).
+type AzureDevOpsService struct {
+	// Kubernetes secret, that contains Base64-encoded Azure DevOps Service Application ID and Client Secret.
+	// See the following page: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-2-for-microsoft-azure-devops-services
+	// +kubebuilder:validation:Required
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,xDescriptors="urn:alm:descriptor:io.kubernetes:Secret"
+	SecretName string `json:"secretName"`
+}
+
 // Container build configuration.
 type ContainerBuildConfiguration struct {
 	// OpenShift security context constraint to build containers.
