@@ -63,26 +63,32 @@ const (
 	DefaultServerTrustStoreConfigMapName   = "ca-certs"
 	DefaultProxyCredentialsSecret          = "proxy-credentials"
 	DefaultGitSelfSignedCertsConfigMapName = "che-git-self-signed-cert"
-	DefaultJavaOpts                        = "-XX:MaxRAMPercentage=85.0"
-	DefaultSecurityContextFsGroup          = 1724
-	DefaultSecurityContextRunAsUser        = 1724
-	DefaultCheServiceAccountName           = "che"
+	// -Dcom.redhat.fips=false workaround allows to run che-server on OpenShift with FIPS enabled
+	// See https://issues.redhat.com/browse/CRW-3301
+	DefaultJavaOpts                 = "-XX:MaxRAMPercentage=85.0 -Dcom.redhat.fips=false"
+	DefaultSecurityContextFsGroup   = 1724
+	DefaultSecurityContextRunAsUser = 1724
+	DefaultCheServiceAccountName    = "che"
 
 	// OAuth
-	BitBucketOAuthConfigClientIdFileName     = "id"
-	BitBucketOAuthConfigClientSecretFileName = "secret"
-	BitBucketOAuthConfigMountPath            = "/che-conf/oauth/bitbucket"
-	BitBucketOAuthConfigPrivateKeyFileName   = "private.key"
-	BitBucketOAuthConfigConsumerKeyFileName  = "consumer.key"
-	GitHubOAuthConfigMountPath               = "/che-conf/oauth/github"
-	GitHubOAuthConfigClientIdFileName        = "id"
-	GitHubOAuthConfigClientSecretFileName    = "secret"
-	GitLabOAuthConfigMountPath               = "/che-conf/oauth/gitlab"
-	GitLabOAuthConfigClientIdFileName        = "id"
-	GitLabOAuthConfigClientSecretFileName    = "secret"
-	OAuthScmConfiguration                    = "oauth-scm-configuration"
-	AccessToken                              = "access_token"
-	IdToken                                  = "id_token"
+	BitBucketOAuthConfigClientIdFileName       = "id"
+	BitBucketOAuthConfigClientSecretFileName   = "secret"
+	BitBucketOAuthConfigMountPath              = "/che-conf/oauth/bitbucket"
+	BitBucketOAuthConfigPrivateKeyFileName     = "private.key"
+	BitBucketOAuthConfigConsumerKeyFileName    = "consumer.key"
+	GitHubOAuthConfigMountPath                 = "/che-conf/oauth/github"
+	GitHubOAuthConfigClientIdFileName          = "id"
+	GitHubOAuthConfigClientSecretFileName      = "secret"
+	AzureDevOpsOAuth                           = "azure-devops"
+	AzureDevOpsOAuthConfigMountPath            = "/che-conf/oauth/azure-devops"
+	AzureDevOpsOAuthConfigClientIdFileName     = "id"
+	AzureDevOpsOAuthConfigClientSecretFileName = "secret"
+	GitLabOAuthConfigMountPath                 = "/che-conf/oauth/gitlab"
+	GitLabOAuthConfigClientIdFileName          = "id"
+	GitLabOAuthConfigClientSecretFileName      = "secret"
+	OAuthScmConfiguration                      = "oauth-scm-configuration"
+	AccessToken                                = "access_token"
+	IdToken                                    = "id_token"
 
 	// Labels
 	KubernetesComponentLabelKey = "app.kubernetes.io/component"
@@ -104,6 +110,7 @@ const (
 	PerUserPVCStorageStrategy      = "per-user"
 	DefaultPvcStorageStrategy      = "per-user"
 	PerWorkspacePVCStorageStrategy = "per-workspace"
+	EphemeralPVCStorageStrategy    = "ephemeral"
 	CommonPVCStorageStrategy       = "common"
 	DefaultAutoProvision           = true
 	DefaultWorkspaceJavaOpts       = "-XX:MaxRAM=150m -XX:MaxRAMFraction=2 -XX:+UseParallelGC " +
@@ -116,9 +123,6 @@ const (
 	DefaultCheTLSSecretName                = "che-tls"
 	DefaultIngressClass                    = "nginx"
 
-	// ImagePuller
-	KubernetesImagePullerOperatorCSV = "kubernetes-imagepuller-operator.v0.0.9"
-
 	// components name
 	DevfileRegistryName                = "devfile-registry"
 	PluginRegistryName                 = "plugin-registry"
@@ -127,6 +131,7 @@ const (
 	GatewayConfigSideCarContainerName  = "configbump"
 	GatewayAuthenticationContainerName = "oauth-proxy"
 	GatewayAuthorizationContainerName  = "kube-rbac-proxy"
+	KubernetesImagePullerComponentName = "kubernetes-image-puller"
 
 	// common
 	CheFlavor             = "che"
