@@ -12,6 +12,8 @@
 package devworkspaceconfig
 
 import (
+	"fmt"
+
 	controllerv1alpha1 "github.com/devfile/devworkspace-operator/apis/controller/v1alpha1"
 	chev2 "github.com/eclipse-che/che-operator/api/v2"
 	"github.com/eclipse-che/che-operator/pkg/common/chetypes"
@@ -85,21 +87,36 @@ func updateWorkspaceConfig(cheCluster *chev2.CheCluster, operatorConfig *control
 		return err
 	}
 
+	if err := updateWorkspacePodSchedulerNameConfig(devEnvironments, operatorConfig.Workspace); err != nil {
+		return err
+	}
+
 	operatorConfig.Workspace.ContainerSecurityContext = nil
 	if cheCluster.IsContainerBuildCapabilitiesEnabled() {
 		operatorConfig.Workspace.ContainerSecurityContext = constants.DefaultWorkspaceContainerSecurityContext.DeepCopy()
 	}
 
+	updateStartTimeout(operatorConfig, devEnvironments.StartTimeoutSeconds)
 	return nil
 }
 
+func updateStartTimeout(operatorConfig *controllerv1alpha1.OperatorConfiguration, startTimeoutSeconds *int32) {
+	if startTimeoutSeconds == nil {
+		// Allow the default start timeout of 5 minutes to be used if devEnvironments.StartTimeoutSeconds is unset
+		operatorConfig.Workspace.ProgressTimeout = ""
+	} else {
+		operatorConfig.Workspace.ProgressTimeout = fmt.Sprintf("%ds", *startTimeoutSeconds)
+	}
+}
+
 func updateWorkspaceStorageConfig(devEnvironments *chev2.CheClusterDevEnvironments, workspaceConfig *controllerv1alpha1.WorkspaceConfig) error {
 	pvcStrategy := utils.GetValue(devEnvironments.Storage.PvcStrategy, constants.DefaultPvcStorageStrategy)
 	isPerWorkspacePVCStorageStrategy := pvcStrategy == constants.PerWorkspacePVCStorageStrategy
-	pvc := map[bool]*chev2.PVC{
-		true:  devEnvironments.Storage.PerWorkspaceStrategyPvcConfig,
-		false: devEnvironments.Storage.PerUserStrategyPvcConfig,
-	}[isPerWorkspacePVCStorageStrategy]
+	pvc := map[string]*chev2.PVC{
+		constants.PerUserPVCStorageStrategy:      devEnvironments.Storage.PerUserStrategyPvcConfig,
+		constants.CommonPVCStorageStrategy:       devEnvironments.Storage.PerUserStrategyPvcConfig,
+		constants.PerWorkspacePVCStorageStrategy: devEnvironments.Storage.PerWorkspaceStrategyPvcConfig,
+	}[pvcStrategy]
 
 	if pvc != nil {
 		if pvc.StorageClass != "" {
@@ -136,3 +153,8 @@ func updateWorkspaceServiceAccountConfig(devEnvironments *chev2.CheClusterDevEnv
 	}
 	return nil
 }
+
+func updateWorkspacePodSchedulerNameConfig(devEnvironments *chev2.CheClusterDevEnvironments, workspaceConfig *controllerv1alpha1.WorkspaceConfig) error {
+	workspaceConfig.SchedulerName = devEnvironments.PodSchedulerName
+	return nil
+}
